@@ -1,5 +1,6 @@
 from abc import abstractmethod
 import os
+import json
 import time
 import warnings
 
@@ -9,7 +10,6 @@ from bmtk.simulator import bionet
 from bmtk.simulator.bionet.io_tools import io
 from bmtk.simulator.bionet import modules as mods
 import bmtk.simulator.utils.simulation_reports as reports
-import h5py
 import neuron
 from neuron import coreneuron
 from neuron import h
@@ -18,6 +18,17 @@ import numpy as np
 
 pc = h.ParallelContext()    # object to access MPI methods
 
+from bmtk.simulator.bionet import nrn
+from bmtk.simulator.bionet import Config as bmtkConfig
+
+MPI_Rank = int(pc.id())
+
+class Config(bmtkConfig):
+
+    def load_nrn_modules(self):
+        # We don't want to load the mechs, x86_64/special will do this for you
+        nrn.load_neuron_modules(None, self.templates_dir)
+
 class CoreSpikesMod(mods.SpikesMod):
     """
     Class continues to function as is, just need to run block before output.
@@ -94,6 +105,7 @@ class CoreSomaReport(mods.SomaReport):
     def __init__(self, *args,**kwargs):
         super(CoreSomaReport, self).__init__(*args,**kwargs)
         self.record_dict = {} # gid:{variable:vector}
+        self.h.cvode.cache_efficient(1)
 
     def initialize(self, sim):
         super(CoreSomaReport, self).initialize(sim)
@@ -186,10 +198,11 @@ class CoreECPMod(mods.EcpMod):
     def finalize(self, sim):
         io.log_info('Node saving ecp report to {}'.format(self.file_name))
         
-        im_steps = {}
+        ecp_steps = {}
 
         for gid in self._local_gids:  # compute ecp only from the biophysical cells
-            im_steps[gid] = np.array([vec for vec in self.cell_imvec[gid]]).T
+            tr = self._rel.get_transfer_resistance(gid)
+            ecp_steps[gid] = np.tensordot(np.array([vec for vec in self.cell_imvec[gid]]).T,tr,axes=((1,1)))
 
         for n_time in range(sim.n_steps):
 
@@ -198,11 +211,7 @@ class CoreECPMod(mods.EcpMod):
 
             for gid in self._local_gids:
 
-                im = im_steps[gid][n_time]
-                tr = self._rel.get_transfer_resistance(gid)
-                                
-                # calculate the ecp/lfp in post processing since we now have a segment by segment recording
-                ecp = np.dot(tr, im)
+                ecp = ecp_steps[gid][n_time][0]
 
                 if gid in self._saved_gids.keys():
                     # save individual contribution
